@@ -5,10 +5,9 @@ from dexp.datasets.open_dataset import glob_datasets
 
 
 @click.command()
-@click.argument('input_paths', nargs=-1)
+@click.argument("input_paths", nargs=-1)
 def info(input_paths):
-    """ Prints out extensive information about dataset.
-    """
+    """Prints out extensive information about dataset."""
 
     input_dataset, input_paths = glob_datasets(input_paths)
 
