@@ -6,32 +6,33 @@ from arbol.arbol import aprint, asection
 from joblib import Parallel, delayed
 from tifffile import memmap
 
-from dexp.datasets.base_dataset import BaseDataset
+from dexp.datasets import BaseDataset
 from dexp.io.io import tiff_save
 
 
-def dataset_tiff(dataset: BaseDataset,
-                 dest_path: str,
-                 channels: Sequence[str],
-                 slicing,
-                 overwrite: bool = False,
-                 project: Union[int, bool] = False,
-                 one_file_per_first_dim: bool = False,
-                 clevel: int = 0,
-                 workers: int = 1,
-                 workersbackend: str = '',
-                 stop_at_exception: bool = True):
-
+def dataset_tiff(
+    dataset: BaseDataset,
+    dest_path: str,
+    channels: Sequence[str],
+    slicing,
+    overwrite: bool = False,
+    project: Union[int, bool] = False,
+    one_file_per_first_dim: bool = False,
+    clevel: int = 0,
+    workers: int = 1,
+    workersbackend: str = "",
+    stop_at_exception: bool = True,
+):
 
     selected_channels = dataset._selected_channels(channels)
 
     aprint(f"getting Dask arrays for channels {selected_channels}")
-    arrays = list([dataset.get_array(channel, per_z_slice=False, wrap_with_dask=True) for channel in selected_channels])
+    arrays = list(dataset.get_array(channel, per_z_slice=False, wrap_with_dask=True) for channel in selected_channels)
 
     if slicing is not None:
         aprint(f"Slicing with: {slicing}")
-        arrays = list([array[slicing] for array in arrays])
-        aprint(f"Done slicing.")
+        arrays = list(array[slicing] for array in arrays)
+        aprint("Done slicing.")
 
     if workers == -1:
         workers = max(1, os.cpu_count() // abs(workers))
@@ -44,18 +45,22 @@ def dataset_tiff(dataset: BaseDataset,
 
         def process(tp):
             try:
-                with asection(f'Saving time point {tp}: '):
+                with asection(f"Saving time point {tp}: "):
                     for channel, array in zip(selected_channels, arrays):
                         tiff_file_path = join(dest_path, f"file{tp}_{channel}.tiff")
                         if overwrite or not os.path.exists(tiff_file_path):
                             stack = array[tp].compute()
 
                             if project is not False and type(project) == int:
-                                # project is the axis for projection, but here we are not considering the T dimension anymore...
+                                # project is the axis for projection, but here we are not considering
+                                # the T dimension anymore...
                                 aprint(f"Projecting along axis {project}")
                                 stack = stack.max(axis=project)
 
-                            aprint(f"Writing time point: {tp} of shape: {stack.shape}, dtype:{stack.dtype} as TIFF file: '{tiff_file_path}', with compression: {clevel}")
+                            aprint(
+                                f"Writing time point: {tp} of shape: {stack.shape}, dtype:{stack.dtype} "
+                                + f"as TIFF file: '{tiff_file_path}', with compression: {clevel}"
+                            )
                             tiff_save(tiff_file_path, stack, compress=clevel)
                             aprint(f"Done writing time point: {tp} !")
                         else:
@@ -64,13 +69,16 @@ def dataset_tiff(dataset: BaseDataset,
                 aprint(error)
                 aprint(f"Error occurred while processing time point {tp} !")
                 import traceback
+
                 traceback.print_exc()
 
                 if stop_at_exception:
                     raise error
 
         if workers > 1:
-            Parallel(n_jobs=workers, backend=workersbackend)(delayed(process)(tp) for tp in range(0, arrays[0].shape[0]))
+            Parallel(n_jobs=workers, backend=workersbackend)(
+                delayed(process)(tp) for tp in range(0, arrays[0].shape[0])
+            )
         else:
             for tp in range(0, arrays[0].shape[0]):
                 process(tp)
@@ -87,13 +95,16 @@ def dataset_tiff(dataset: BaseDataset,
                 aprint(f"File {tiff_file_path} already exists! Set option -w to overwrite.")
                 return
 
-            with asection(f"Saving array ({array.shape}, {array.dtype}) for channel {channel} into TIFF file at: {tiff_file_path}:"):
+            with asection(
+                f"Saving array ({array.shape}, {array.dtype}) for channel {channel} into "
+                + f"TIFF file at: {tiff_file_path}:"
+            ):
 
                 shape = array.shape
 
                 if project is not False and type(project) == int:
                     shape = list(shape)
-                    shape.pop(1+project)
+                    shape.pop(1 + project)
                     shape = tuple(shape)
 
                 memmap_image = memmap(tiff_file_path, shape=shape, dtype=array.dtype, bigtiff=True, imagej=True)
@@ -110,18 +121,12 @@ def dataset_tiff(dataset: BaseDataset,
                     memmap_image[tp] = stack
 
                 if workers > 1:
-                    Parallel(n_jobs=workers, backend=workersbackend)(delayed(process)(tp) for tp in range(0, array.shape[0]))
+                    Parallel(n_jobs=workers, backend=workersbackend)(
+                        delayed(process)(tp) for tp in range(0, array.shape[0])
+                    )
                 else:
                     for tp in range(0, array.shape[0]):
                         process(tp)
 
                 memmap_image.flush()
                 del memmap_image
-
-## NOTES: color coded max projection:
-# > data = numpy.random.randint(0, 255, (256, 256, 3), 'uint8')
-# >>> imwrite('temp.tif', data, photometric='color')
-#
-# https://colorcet.holoviz.org/user_guide/index.html
-# https://github.com/MMesch/cmap_builder
-#
