@@ -5,32 +5,18 @@ from dexp.optics.psf.microscope_psf import MicroscopePSF
 
 
 def nikon16x08na(xy_size=17, z_size=17, dxy=0.485, dz=2, wvl=0.561, NA=0.8):
-    return generate_psf(dxy=dxy,
-                        dz=dz,
-                        xy_size=xy_size,
-                        z_size=z_size,
-                        M=16,
-                        NA=NA,
-                        n=1.33,
-                        wd=3000,
-                        tl=165.0 * 1.0e+3,
-                        wvl=wvl)
+    return generate_psf(
+        dxy=dxy, dz=dz, xy_size=xy_size, z_size=z_size, M=16, NA=NA, n=1.33, wd=3000, tl=165.0 * 1.0e3, wvl=wvl
+    )
 
 
 def olympus20x10na(xy_size=17, z_size=17, dxy=0.439, dz=1.8, wvl=0.561, NA=1.0):
-    return generate_psf(dxy=dxy,
-                        dz=dz,
-                        xy_size=xy_size,
-                        z_size=z_size,
-                        M=20,
-                        NA=NA,
-                        n=1.33,
-                        wd=2000,
-                        tl=133.0 * 1.0e+3,
-                        wvl=wvl)
+    return generate_psf(
+        dxy=dxy, dz=dz, xy_size=xy_size, z_size=z_size, M=20, NA=NA, n=1.33, wd=2000, tl=133.0 * 1.0e3, wvl=wvl
+    )
 
 
-def generate_psf(dxy, dz, xy_size, z_size, M=16, NA=0.8, n=1.33, wd=3000, tl=133.0 * 1.0e+3, wvl=561.):
+def generate_psf(dxy, dz, xy_size, z_size, M=16, NA=0.8, n=1.33, wd=3000, tl=133.0 * 1.0e3, wvl=561.0):
     """
     Generates a 3D PSF array.
 
@@ -57,13 +43,7 @@ def generate_psf(dxy, dz, xy_size, z_size, M=16, NA=0.8, n=1.33, wd=3000, tl=133
     pz = numpy.arange(0, lz, dz)
 
     # gLXYZParticleScan(self, dxy, xy_size, pz, normalize = True, wvl = 0.6, zd = None, zv = 0.0):
-    psf_xyz_array = psf_gen.gLXYZParticleScan(
-        dxy=dxy,
-        xy_size=xy_size,
-        pz=pz,
-        zv=z_offset,
-        wvl=wvl
-    )
+    psf_xyz_array = psf_gen.gLXYZParticleScan(dxy=dxy, xy_size=xy_size, pz=pz, zv=z_offset, wvl=wvl)
 
     psf_xyz_array /= psf_xyz_array.sum()
 
