@@ -1,21 +1,22 @@
 import numpy
 from arbol import aprint
 
-from dexp.processing.backends.backend import Backend
-from dexp.processing.backends.numpy_backend import NumpyBackend
 from dexp.utils import xpArray
+from dexp.utils.backends import Backend, NumpyBackend
 
 
-def equalise_intensity(image1: xpArray,
-                       image2: xpArray,
-                       zero_level=90,
-                       quantile_low=0.01,
-                       quantile_high=0.99,
-                       project_axis: int = 0,
-                       max_voxels: int = 1e7,
-                       correction_ratio: float = None,
-                       copy: bool = True,
-                       internal_dtype=None):
+def equalise_intensity(
+    image1: xpArray,
+    image2: xpArray,
+    zero_level=90,
+    quantile_low=0.01,
+    quantile_high=0.99,
+    project_axis: int = 0,
+    max_voxels: int = 1e7,
+    correction_ratio: float = None,
+    copy: bool = True,
+    internal_dtype=None,
+):
     """
     Equalise intensity between two images
 
@@ -27,8 +28,9 @@ def equalise_intensity(image1: xpArray,
     quantile_low, quantile_high : quantile for computing the robust min and max values in image
     project_axis : Axis over which to project image to speed up computation
     max_voxels : maximal number of voxels to use to compute min and max values.
-    correction_ratio : If provided, this value is used instead of calculating the equalisation value based on the two images.
-    This is the value that should be multiplied to the second image (image2) so as to equalise it to teh first image (image1).
+    correction_ratio : If provided, this value is used instead of calculating the equalisation value based
+        on the two images. This is the value that should be multiplied to the second image (image2)
+        so as to equalise it to teh first image (image1).
     copy : Set to True to force copy of images.
     internal_dtype : dtype to use internally for computation.
 
@@ -69,8 +71,8 @@ def equalise_intensity(image1: xpArray,
         strided_image2 = proj_image2.ravel()[::reduction].astype(numpy.float32, copy=False)
 
         # We determine a robust maximum for voxel intensities:
-        highvalue1 = xp.percentile(strided_image1, q=quantile_high * 100, interpolation='higher')
-        highvalue2 = xp.percentile(strided_image2, q=quantile_high * 100, interpolation='higher')
+        highvalue1 = xp.percentile(strided_image1, q=quantile_high * 100, interpolation="higher")
+        highvalue2 = xp.percentile(strided_image2, q=quantile_high * 100, interpolation="higher")
 
         # we set a 'high-value' threshold to the minimum of both robust maximums:
         threshold = min(highvalue1, highvalue2)
@@ -89,9 +91,9 @@ def equalise_intensity(image1: xpArray,
         lowvalue2 = xp.percentile(strided_image2, q=quantile_low * 100)
 
         # Compute ratios:
-        range1 = highvalues1 - lowvalue1
-        range2 = highvalues2 - lowvalue2
-        ratios = (range1 / range2)
+        range1 = xp.clip(highvalues1 - lowvalue1, 0, None)
+        range2 = xp.clip(highvalues2 - lowvalue2, 0, None)
+        ratios = range1 / range2
 
         # Keep only valid ratios:
         valid = xp.logical_and(range1 != 0, range2 != 0)
@@ -103,16 +105,22 @@ def equalise_intensity(image1: xpArray,
         # Number of values in ratio:
         nb_values = ratios.size
         if nb_values < 16:
-            raise ValueError(f"No enough values ({nb_values}<16) to compute correction ratio! Relax percentile or reduction! ")
+            raise ValueError(
+                f"No enough values ({nb_values}<16) to compute correction ratio! Relax percentile or reduction! "
+            )
         elif nb_values < 128:
-            aprint(f"Warning: too few ratio values ({nb_values}<128) to compute correction ratio! Relax percentile or reduction!")
+            aprint(
+                f"Warning: too few ratio values ({nb_values}<128)"
+                + "to compute correction ratio! Relax percentile or reduction!"
+            )
 
-        correction_ratio = xp.percentile(ratios.astype(internal_dtype, copy=False), q=50)
+        correction_ratio = xp.median(ratios.astype(internal_dtype, copy=False))
     else:
         correction_ratio = Backend.to_backend(correction_ratio, dtype=internal_dtype)
 
     # remove zero level and clip:
     if zero_level != 0:
+        # FIXME: shouldn't the order be inverted? this might create edges
         image1 = xp.clip(image1, a_min=zero_level, a_max=None, out=image1)
         image1 -= zero_level
         image2 = xp.clip(image2, a_min=zero_level, a_max=None, out=image2)
@@ -142,6 +150,6 @@ def equalise_intensity(image1: xpArray,
     #
     #     viewer = Viewer()
     #     viewer.add_image(_c(image1), name='image_1')
-    #     viewer.add_image(_c(image1), name='image_2')
+    #     viewer.add_image(_c(image2), name='image_2')
 
     return image1, image2, correction_ratio
