@@ -1,26 +1,27 @@
 from typing import Optional
 
-from dexp.processing.backends.backend import Backend
-from dexp.processing.backends.numpy_backend import NumpyBackend
 from dexp.processing.filters.sobel_filter import sobel_filter
 from dexp.processing.utils.blend_images import blend_images
 from dexp.processing.utils.element_wise_affine import element_wise_affine
 from dexp.processing.utils.fit_shape import fit_to_shape
 from dexp.utils import xpArray
+from dexp.utils.backends import Backend, NumpyBackend
 
 
-def fuse_tg_nd(image_a: xpArray,
-               image_b: xpArray,
-               downscale: Optional[int] = 2,
-               sharpness: Optional[float] = 24,
-               tenengrad_smoothing: Optional[int] = 4,
-               blend_map_smoothing: Optional[int] = 10,
-               bias_axis: Optional[int] = None,
-               bias_exponent: Optional[float] = 3,
-               bias_strength: Optional[float] = 2,
-               clip: Optional[bool] = True,
-               internal_dtype=None,
-               _display_blend_map: bool = False):
+def fuse_tg_nd(
+    image_a: xpArray,
+    image_b: xpArray,
+    downscale: Optional[int] = 2,
+    sharpness: Optional[float] = 24,
+    tenengrad_smoothing: Optional[int] = 4,
+    blend_map_smoothing: Optional[int] = 10,
+    bias_axis: Optional[int] = None,
+    bias_exponent: Optional[float] = 3,
+    bias_strength: Optional[float] = 2,
+    clip: Optional[bool] = True,
+    internal_dtype=None,
+    _display_blend_map: bool = False,
+):
     """
     Fuses two images by picking regions from one or the other image based on the local image quality
     measured by using the magnitude of the Sobel gradient -- similarly as in the Tenengrad focus metric.
@@ -157,14 +158,16 @@ def fuse_tg_nd(image_a: xpArray,
 
     if _display_blend_map:
         from napari import Viewer, gui_qt
+
         with gui_qt():
+
             def _c(array):
                 return Backend.to_numpy(array)
 
             viewer = Viewer()
-            viewer.add_image(_c(image_a), name='image_a', contrast_limits=(0, 600))
-            viewer.add_image(_c(image_b), name='image_b', contrast_limits=(0, 600))
-            viewer.add_image(_c(blend_map), name='blend_map')
-            viewer.add_image(_c(image_fused), name='image_fused', contrast_limits=(0, 600))
+            viewer.add_image(_c(image_a), name="image_a", contrast_limits=(0, 600))
+            viewer.add_image(_c(image_b), name="image_b", contrast_limits=(0, 600))
+            viewer.add_image(_c(blend_map), name="blend_map")
+            viewer.add_image(_c(image_fused), name="image_fused", contrast_limits=(0, 600))
 
     return image_fused
